@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,12 +13,14 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::System::DB',
 );
 
 sub GetDisplayPath {
-    return 'Database';
+    return Translatable('Database');
 }
 
 sub Run {
@@ -31,14 +33,26 @@ sub Run {
         return $Self->GetResults();
     }
 
+    # Default storage engine variable has changed its name in MySQL 5.5.3, we need to support both of them for now.
+    #   <= 5.5.2 storage_engine
+    #   >= 5.5.3 default_storage_engine
     my $DefaultStorageEngine;
-
     $DBObject->Prepare( SQL => "show variables like 'storage_engine'" );
     while ( my @Row = $DBObject->FetchrowArray() ) {
         $DefaultStorageEngine = $Row[1];
+    }
+
+    if ( !$DefaultStorageEngine ) {
+        $DBObject->Prepare( SQL => "show variables like 'default_storage_engine'" );
+        while ( my @Row = $DBObject->FetchrowArray() ) {
+            $DefaultStorageEngine = $Row[1];
+        }
+    }
+
+    if ($DefaultStorageEngine) {
         $Self->AddResultOk(
             Identifier => 'DefaultStorageEngine',
-            Label      => 'Default Storage Engine',
+            Label      => Translatable('Default Storage Engine'),
             Value      => $DefaultStorageEngine,
         );
     }
@@ -55,15 +69,15 @@ sub Run {
     if (@TablesWithDifferentStorageEngine) {
         $Self->AddResultProblem(
             Identifier => 'TablesWithDifferentStorageEngine',
-            Label      => 'Table Storage Engine',
+            Label      => Translatable('Table Storage Engine'),
             Value      => join( ', ', @TablesWithDifferentStorageEngine ),
-            Message    => 'Tables with a different storage engine than the default engine were found.'
+            Message    => Translatable('Tables with a different storage engine than the default engine were found.')
         );
     }
     else {
         $Self->AddResultOk(
             Identifier => 'TablesWithDifferentStorageEngine',
-            Label      => 'Table Storage Engine',
+            Label      => Translatable('Table Storage Engine'),
             Value      => '',
         );
     }
@@ -71,16 +85,4 @@ sub Run {
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<http://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
-
-=cut
-
 1;
